@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-package TextFileParser 0.203;
+package TextFileParser 0.204;
 
 # ABSTRACT: an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
@@ -163,13 +163,13 @@ TextFileParser - an extensible Perl class to parse any text file by specifying g
 
 =head1 VERSION
 
-version 0.203
+version 0.204
 
 =head1 SYNOPSIS
 
     use TextFileParser;
 
-    my $parser = new TextFileParser;
+    my $parser = TextFileParser->new();
     $parser->read(shift @ARGV);
     print $parser->get_records, "\n";
 
@@ -209,7 +209,7 @@ That's it! Now in C<main::> you can write the following.
 
     use CSVParser;
     
-    my $csvp = new CSVParser;
+    my $csvp = CSVParser->new();
     $csvp->read(shift @ARGV);
 
 =head3 Error checking
@@ -275,7 +275,7 @@ This is where L<roles|Role::Tiny> are very useful.
 
 Takes no arguments. Returns a blessed reference of the object.
 
-    my $pars = new TextFileParser;
+    my $pars = TextFileParser->new();
 
 This C<$pars> variable will be used in examples below.
 
